# -*- coding:utf-8 -*-
import tkinter
import tkinter.messagebox
import random

# キャンバスの横方向・縦方向のサイズ（px）
CANVAS_SIZE = 400

# ラインの数
NUM_LINE = 10

# 色の設定
BOARD_COLOR = 'burlywood3' # 盤面の背景色
YOUR_COLOR = 'black' # あなたの石の色

# プレイヤーを示す値
YOU = 1

class Gobang():
    def __init__(self, master):
        '''コンストラクタ'''

        self.master = master # 親ウィジェット
        self.player = YOU # 次に置く石の色
        self.board = None # 盤面上の石を管理する２次元リスト
        self.nextDisk = None

        # ウィジェットの作成
        self.createWidgets()


        # 五目並べゲームの初期化
        self.initGobang()


    def createWidgets(self):
        '''ウィジェットを作成・配置する'''

        # キャンバスの作成
        self.canvas = tkinter.Canvas(
            self.master,
            bg=BOARD_COLOR,
            width=CANVAS_SIZE,
            height=CANVAS_SIZE,
            highlightthickness=0
        )
        self.canvas.pack(padx=10, pady=10)




    def initGobang(self):
        '''ゲームの初期化を行う'''

        # 盤面上の石を管理する２次元リストを作成（最初は全てNone）
        self.board = [[None] * (NUM_LINE) for i in range(NUM_LINE)]

        # 線と線の間隔（px）を計算
        self.interval = CANVAS_SIZE // (NUM_LINE + 1)

        # 交点描画位置の左上オフセット
        self.offset_x = self.interval
        self.offset_y = self.interval

        # 縦線を描画
        for x in range(NUM_LINE):
 
            # 線の開始・終了座標を計算
            xs = x * self.interval + self.offset_x
            ys = self.offset_y
            xe = xs
            ye = (NUM_LINE - 1) * self.interval + self.offset_y
                
            # 線を描画
            self.canvas.create_line(
                xs, ys,
                xe, ye,
            )

        # 横線を描画
        for y in range(NUM_LINE):
 
            # 線の開始・終了座標を計算
            xs = self.offset_x
            ys = y * self.interval + self.offset_y
            xe = (NUM_LINE - 1) * self.interval + self.offset_x
            ye = ys
                
            # 線を描画
            self.canvas.create_line(
                xs, ys,
                xe, ye,
            )



# スクリプト処理ここから
app = tkinter.Tk()
app.title('五目並べ')
gobang = Gobang(app)
app.mainloop()
